#ifndef APPLICATION_H
#define APPLICATION_H

#include <QApplication>

class MainWindow;

class Application : public QApplication
{
    Q_OBJECT
public:
    explicit Application(int & argc, char ** argv);
    ~Application();

    bool registerService();
    int execute();

private:
    void visitUrl(QString url, bool fakeUserAgent);

private:
    MainWindow* newWindow();

private:
    MainWindow  *m_pMainWindow;

signals:

public slots:
    // dbus
    void open(const QString &url, bool fakeAgent);
};

#endif // APPLICATION_H
